@@ -39,7 +39,7 @@ from meadowrun.instance_selection import (
     CloudInstance,
     CloudInstanceType,
     OnDemandOrSpotType,
-    Resources,
+    ResourcesInternal,
     choose_instance_types_for_job,
 )
 
@@ -330,6 +330,7 @@ async def launch_ec2_instance(
     user_data: Optional[str] = None,
     key_name: Optional[str] = None,
     tags: Optional[Dict[str, str]] = None,
+    volume_size_gb: int = 100,
 ) -> LaunchEC2InstanceResult:
     """
     Launches the specified EC2 instance. See derived classes of LaunchEC2InstanceResult
@@ -343,7 +344,7 @@ async def launch_ec2_instance(
                 "DeviceName": "/dev/sda1",
                 "Ebs": {
                     "DeleteOnTermination": True,
-                    "VolumeSize": 100,
+                    "VolumeSize": volume_size_gb,
                     "VolumeType": "gp2",
                 },
             }
@@ -458,7 +459,7 @@ async def _launch_instance_continuation(instance: Any) -> str:
 
 
 async def launch_ec2_instances(
-    resources_required_per_job: Resources,
+    resources_required_per_job: ResourcesInternal,
     num_jobs: int,
     ami_id: str,
     region_name: Optional[str] = None,
