@@ -67,26 +67,26 @@ from meadowrun.run_job_core import JobCompletion, SshHost
 # replicate into each region.
 _AMIS = {
     "plain": {
-        "us-east-2": "ami-060b22d1a6cc2015d",
-        "us-east-1": "ami-00ddb42386d3b53a7",
-        "us-west-1": "ami-0ad21db87a876b6a3",
-        "us-west-2": "ami-078c08b39693de44a",
-        "eu-central-1": "ami-0eacfa886550c9ebf",
-        "eu-west-1": "ami-0e9ef4f6ab8e046d9",
-        "eu-west-2": "ami-02bd2b9d2570224ad",
-        "eu-west-3": "ami-09d8d5eb88a3448c2",
-        "eu-north-1": "ami-0662349972ea33070",
+        "us-east-2": "ami-0d948ec3621004e36",
+        "us-east-1": "ami-0f22fcfd0529f7282",
+        "us-west-1": "ami-093a1d387f032a3fa",
+        "us-west-2": "ami-0b5da5aea62fe5b07",
+        "eu-central-1": "ami-067f204dd8e04107c",
+        "eu-west-1": "ami-00eb980c50e9da8e0",
+        "eu-west-2": "ami-07a8039ca7e75b687",
+        "eu-west-3": "ami-0f3ef3a78c8ff7823",
+        "eu-north-1": "ami-05006b18936a4c1aa",
     },
     "cuda": {
-        "us-east-2": "ami-0812c941def86f2d0",
-        "us-east-1": "ami-0830a4ce808fc181c",
-        "us-west-1": "ami-08b7e850b0322cf84",
-        "us-west-2": "ami-028f438b7f6adf083",
-        "eu-central-1": "ami-08fccdf3fa0021fe2",
-        "eu-west-1": "ami-0278ff8a8933ec7fc",
-        "eu-west-2": "ami-0afd03a83578577ce",
-        "eu-west-3": "ami-07cee6f65999ac8d2",
-        "eu-north-1": "ami-0e5183ba0f8a902a5",
+        "us-east-2": "ami-0a7e23e38b9f2a1cd",
+        "us-east-1": "ami-0dabcc24524177d49",
+        "us-west-1": "ami-07b927135da43efc9",
+        "us-west-2": "ami-0f20679734014d552",
+        "eu-central-1": "ami-0b530745ee21083da",
+        "eu-west-1": "ami-0f89dc1a2da737d36",
+        "eu-west-2": "ami-01fcfce17a7c6143c",
+        "eu-west-3": "ami-03409615e26aac085",
+        "eu-north-1": "ami-06a7590fa15af0798",
     },
 }
 SSH_USER = "ubuntu"
@@ -352,6 +352,13 @@ class EC2InstanceRegistrar(InstanceRegistrar[_InstanceState]):
         )
         return success
 
+    def allocate_jobs_to_instance_max_chunk(self) -> int:
+        # the limit for update/conditional expressions in DynamoDB is 4KB:
+        # https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/ServiceQuotas.html
+        # We hit this at around 90 jobs, and we give ourselves a bit of extra buffer
+        # here
+        return 85
+
     async def deallocate_job_from_instance(
         self, instance: _InstanceState, job_id: str
     ) -> bool:
