@@ -7,12 +7,13 @@ should not refer to any outside code
 """
 from __future__ import annotations
 
-from typing import Callable, Tuple, TypeVar, Union, Set, overload
-from typing_extensions import Literal
+from typing import TYPE_CHECKING, Callable, Set, Tuple, TypeVar, Union, overload
+
+if TYPE_CHECKING:
+    from typing_extensions import Literal
 
 import botocore.exceptions
 
-
 _T = TypeVar("_T")
 
 # a dynamodb table that holds information about EC2 instances we've created and what has
@@ -21,12 +22,13 @@ _EC2_ALLOC_TABLE_NAME = "meadowrun_ec2_alloc_table"
 
 # names of attributes/keys in the EC2 alloc table
 _PUBLIC_ADDRESS = "public_address"
-_LOGICAL_CPU_AVAILABLE = "logical_cpu_available"
-_LOGICAL_CPU_ALLOCATED = "logical_cpu_allocated"
-_MEMORY_GB_AVAILABLE = "memory_gb_available"
-_MEMORY_GB_ALLOCATED = "memory_gb_allocated"
+_INSTANCE_ID = "instance_id"
+_RESOURCES_AVAILABLE = "resources_available"
+_NON_CONSUMABLE_RESOURCES = "non_consumable_resources"
+_RESOURCES_ALLOCATED = "resources_allocated"
 _ALLOCATED_TIME = "allocated_time"
 _LAST_UPDATE_TIME = "last_update_time"
+_PREVENT_FURTHER_ALLOCATION = "prevent_further_allocation"
 _RUNNING_JOBS = "running_jobs"
 _JOB_ID = "job_id"
 
